// Defines und Funktionen des Nikospiels

#define TASTER1         0             // Port PD0 - meinTasterByte Bit 0
#define TASTER2         1             // Port PD1 - meinTasterByte Bit 1
#define TASTER3         3             // Port PD3 - meinTasterByte Bit 3
#define TASTER4         4             // Port PD4 - meinTasterByte Bit 4
#define EIN_TASTER      2             // Port PD2 - meinTasterByte Bit 2
#define SUMMER          5             // Port PD5 
#define LED1            0             // Port PD0
#define LED2            1             // Port PD1  
#define LED3            3             // Port PD3
#define LED4            4             // Port PD4   
#define DISPLAY_Vo      4             // Port PB4   
#define DISPLAY_POWER   6             // Port PD6   

#define TIMER0_OVR      1
#define TIMER1_OVR      2

#define F_CPU           1000000UL     // Systemtakt 1 MHz

int AVRInit(void)
{
   // ================= Initialisierung ===================

    // ---------- Portpinbelegung und Definition ----------- 
	
    // ------ Port D (Taster1/2/3/4 und EIN_TASTER) ------
    DDRD  |= ((1<<SUMMER) | (1<<DISPLAY_POWER));                                                     // setzt Port-Pins als Ausgnge fest  
    DDRD  &= ~((1<<TASTER1) | (1<<TASTER2) | (1<<TASTER3) | (1<<TASTER4) | (1<<EIN_TASTER));       // definiert Port-Pins fr TASTER als Eingnge 

    PORTD |=  (1<<DISPLAY_POWER);                                                                     // setze Port-Pin auf High-Pegel 
    PORTD &= ~((1<<TASTER1) | (1<<TASTER2) | (1<<TASTER3) | (1<<TASTER4) | (1<<EIN_TASTER));       // deaktiviere internen Pull-Ups von Port-Pin



    // --------------- Port B ------------- 
    DDRB  |=  (1<<DISPLAY_Vo);                                  // setzt Port-Pin als Ausgnge fest
 	PORTB |=  (1<<DISPLAY_Vo);                                  // setze Port-Pin auf High-Pegel 


    // ------- Interrupt fr EIN_TASTER definieren ---------      
    MCUCR  |= (1<<ISC00) | (1<<ISC01);                         // ISC00=1, ISC01=1  steigende Flanke an INT0 erzeugt einen Interrupt 
    

    // --------------- Timer0 fr CTC-Modus ----------------    // Timer0 ist ein 8Bit Timer und wird hier im CTC-Modus verwendet
    // TCCR0A: COM0A1/COM0A0/COM0B1/COM0B0/-/-/WGM01/WGM00 
    // TCCR0B: FOC0A/FOC0B/-/-/WGM02/CS02/CS01/CS00
    // 
    // WGM02=0, WGM01=1, WGM00=0 => CTC-Modus aktiviert
    // COM0B1=0 ,COM0B0=0        => OC0B disconnected / Pin-Funktion aktiv
    // CS02=0 , CS01=1 ; CS00=1  => Vorteiler 64      
    TCCR0A = 0b00000010;                                         
    TCCR0B = 0b00000011;   										



    // -------- Timer1 fr interne Zeitmessung ---------        // Timer1 ist ein 16Bit Timer
    TIMSK  |= (1<<TOIE1);                                      // TOIE1=1 Interrupt enable     
    TCCR1B |= (0<<CS12) | (1<<CS11) | (1<<CS10);				// CS12=0, CS11=1, CS10=1 => Vorteiler 64;  1.000.000 Hz : 64 = 15.625 Hz  
	return 0;
}

int Ssleep(int Sekunden)
{
for (int j = 1; j < 3*Sekunden; j++)// Delay von ca. 1 sec.
					{
					_delay_loop_2(60000); //max. INTEGER-Wert beachten!
					}
return 0;
}